@@ -10,7 +10,6 @@
 #' @param rotate logical indicating whether to rotate text following the contour.
 #' @param stroke numerical indicating width of stroke relative to the size of
 #' the text. Ignored if less than zero.
-#' @param stroke.color any valid colour.
 #' @param label.placement A function for placing labels (see `label_placement_flattest()`).
 #'
 #' @details
@@ -28,6 +27,11 @@
 #'
 #' g + geom_text_contour(aes(z = value), stroke = 0.2)
 #'
+#' g + geom_text_contour(aes(z = value), stroke = 0.2, stroke.colour = "red")
+#'
+#' g + geom_text_contour(aes(z = value, stroke.colour = ..level..), stroke = 0.2) +
+#'     scale_colour_gradient(aesthetics = "stroke.colour", guide = "none")
+#'
 #' g + geom_text_contour(aes(z = value), rotate = FALSE)
 #'
 #' g + geom_text_contour(aes(z = value),
@@ -53,6 +57,7 @@
 #' \item \code{alpha}
 #' \item \code{angle}
 #' \item \code{colour}
+#' \item \code{stroke.color}
 #' \item \code{family}
 #' \item \code{fontface}
 #' \item \code{group}
@@ -78,7 +83,7 @@ geom_text_contour <- function(mapping = NULL, data = NULL,
                       nudge_x = 0,
                       nudge_y = 0,
                       stroke = 0,
-                      stroke.color = "white",
+                      # stroke.color = "white",
                       check_overlap = FALSE,
                       # xwrap = NULL,
                       # ywrap = NULL,
@@ -110,7 +115,7 @@ geom_text_contour <- function(mapping = NULL, data = NULL,
             parse = parse,
             check_overlap = check_overlap,
             stroke = stroke,
-            stroke.color = stroke.color,
+            # stroke.color = stroke.color,
             # xwrap = xwrap,
             # ywrap = ywrap,
             label.placement = label.placement,
@@ -129,19 +134,21 @@ GeomTextContour <- ggplot2::ggproto("GeomTextContour", ggplot2::Geom,
    required_aes = c("x", "y", "label"),
    default_aes = ggplot2::aes(colour = "black", size = 3.88, angle = 0,
                               hjust = 0.5, vjust = 0.5, alpha = NA, family = "",
-                              fontface = 1, lineheight = 1.2),
+                              fontface = 1, lineheight = 1.2,
+                              stroke.colour = "white"),
 
    draw_panel = function(data, panel_params, coord, parse = FALSE,
                          na.rm = FALSE, check_overlap = FALSE, min.size = 20,
                          skip = 1, rotate = FALSE, gap = NULL,
                          label.placement = label_placement_flattest(),
-                         stroke = 0, stroke.colour = "white") {
+                         stroke = 0) {
        data <- data.table::as.data.table(coord$transform(data, panel_params))
        min.size <- ceiling(min.size)
        if (min.size %% 2 == 0) {
            min.size <- min.size - 1
        }
 
+
        breaks <- unique(data$level)
        breaks.cut <- breaks[seq(1, length(breaks), by = skip + 1)]
 
@@ -182,7 +189,7 @@ GeomTextContour <- ggplot2::ggproto("GeomTextContour", ggplot2::Geom,
            group = interaction(data$group, data$piece),
            default.units = "native",
            hjust = hjust, vjust = vjust,
-           bg.r = stroke, bg.color = stroke.colour,
+           bg.r = stroke, bg.color = data$stroke.colour,
            position = label.placement,
 
                col = scales::alpha(data$colour, data$alpha),
@@ -200,4 +207,15 @@ GeomTextContour <- ggplot2::ggproto("GeomTextContour", ggplot2::Geom,
    draw_key = ggplot2::draw_key_text
 )
 
-
+#' Scale for stroke.colour
+#'
+#' @param ... parameters sent to [ggplot2::scale_color_continuous]
+#'
+#'
+#' @export
+#' @keywords internal
+#' @usage NULL
+#' @format NULL
+scale_stroke.colour_continuous <- function(...) {
+    ggplot2::scale_color_continuous(aesthetics = "stroke.colour", guide = "none")
+}
