@@ -20,15 +20,24 @@ test_that("geom_contour2 mimics geom_contour", {
                             guides(fill = "none"))
 })
 
-    test_that("accepts function in breaks", {
-        expect_doppelganger("contour2-fun",
+test_that("accepts function in breaks", {
+    expect_doppelganger("contour2-fun",
                         ggplot(geo, aes(lon, lat)) +
                             geom_contour2(aes(z = gh), breaks = MakeBreaks(50)))
 })
 
 
+file <- system.file("extdata", "met.txt", package = "metR")
+df <- read.table(file, header = FALSE)
+
+test_that("df was read correctly",
+          expect_known_hash(df, "7a56064fc1")
+)
+
+
+
+
 test_that("global.breaks work", {
-    df <- read.table('met.txt', header = FALSE)
 
     expect_doppelganger("contour2-global.breaks",
                         ggplot(df, aes(x=V1, y=V2, z=V3)) +
@@ -37,13 +46,27 @@ test_that("global.breaks work", {
                             guides(fill = "none") +
                             facet_grid(. ~ V4))
 
-    expect_doppelganger("contour2-global.breaks_full",
-                        ggplot(df, aes(x=V1, y=V2, z=V3)) +
-                            geom_contour_fill(global.breaks = FALSE) +
-                            geom_contour2(global.breaks = FALSE) +
-                            geom_text_contour(global.breaks = FALSE) +
-                            guides(fill = "none") +
-                            facet_grid(. ~ V4))
+    # expect_doppelganger("contour2-global.breaks_full",
+    #                     ggplot(df, aes(x=V1, y=V2, z=V3)) +
+    #                         geom_contour_fill(global.breaks = FALSE) +
+    #                         geom_contour2(global.breaks = FALSE) +
+    #                         geom_text_contour(global.breaks = FALSE) +
+    #                         guides(fill = "none") +
+    #                         facet_grid(. ~ V4)
+    #                     )
 })
 
 
+
+test_that("contour_tanaka works", {
+    expect_doppelganger("tanaka",
+                        ggplot(geo, aes(lon, lat)) +
+                            geom_contour_filled(aes(z = gh)) +
+                            geom_contour_tanaka(aes(z = gh))
+    )
+    # expect_doppelganger("tanaka_smooth",
+    #                     ggplot(geo, aes(lon, lat)) +
+    #                         geom_contour_filled(aes(z = gh)) +
+    #                         geom_contour_tanaka(aes(z = gh), smooth = TRUE)
+    # )
+})
